.. _dialect_specific_features:

Dialect specific features
=========================

Several dialects handle spatial data in different ways. ``GeoAlchemy2`` tries to hide these
differences but sometimes manual tweaks are needed.

.. toctree::
   :maxdepth: 1

   mysql_mariadb_dialect
   spatialite_dialect
